Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Order defines the order of severities from highest to lowest. Order = []string{"critical", "high", "medium", "low", "unknown"} )
Functions ¶
func CountBySeverity ¶
CountBySeverity counts vulnerabilities by their severity.
func FormatTitleCase ¶
FormatTitleCase formats a severity string in title case without styling.
func IndexOf ¶
IndexOf returns the index of a string in a slice, or the length of the slice if not found.
func InitializeCounts ¶
InitializeCounts creates a new map with all severity counts initialized to 0.
func NormalizeAuth ¶
NormalizeAuth normalizes an authentication type string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.